#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/4/19 18:58
# @Author  : yaitza
# @Email   : yaitza@foxmail.com
import yaml

class YamlHandler():
	def __init__(self, file_path):
		self.file_path = file_path

	def load(self):
		with open(self.file_path, 'r', encoding='utf-8') as f:
			raw = yaml.safe_load(f.read())
		return raw


import unicodedata
import random
import time


class StringHelper(object):
    @staticmethod
    def is_number(input_str) -> bool:
        """
        验证字符串为数字。
        @param input_str: 输入字符串或数字
        @return: True or False
        """
        if type(input_str) is int:
            return True

        if type(input_str) is str:
            try:
                unicodedata.digit(input_str)
                return True
            except (TypeError, ValueError):
                pass
        return False

    @staticmethod
    def random_generate_str(int_nu) -> str:
        """
        生成随机指定长度的字符串。
        @param int_nu: 输入字符串
        @return: 返回随机的字符串
        """
        str_template = 'zyxwvutsrqponmlkjihgfedcba'

        while len(str_template) < int_nu:
            str_template += str_template

        return time.strftime('%Y%m%d%H%M%S_', time.localtime()) + "".join([item for item in random.sample(str_template, int_nu)])


if __name__ == "__main__":
    print(StringHelper.random_generate_str(4))
    print(StringHelper.random_generate_str(30))
    print(time.strftime('%Y%m%d%H%M%S', time.localtime()))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/10/13 09:21
# @Author  : yaitza
# @Email   : yaitza@foxmail.com

from dg_itest.servers.dg_servers.dg_requsts import DgRequests

class MetaSingleton(type):
    def __init__(self, *args, **kwargs):
        self.__instance = None

    def __call__(self, *args, **kwargs):
        if not self.__instance:
            self.__instance = super().__call__(*args, **kwargs)
        return self.__instance


class DgSingleton(metaclass=MetaSingleton):
    apis = DgRequests()




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/4/1 09:34
# @Author  : yaitza
# @Email   : yaitza@foxmail.com
import os
import platform
from pathlib import *
class EnvGenerater:
    """
    自动生成allure report对应Environment配置文件environment.properties.
    """

    @staticmethod
    def generate_env_file(host_url: str, file_dir: Path):
        """
        生成allure report对应Environment配置文件environment.properties.
        """
        file_name = "environment.properties"
        file_path = file_dir.joinpath(file_name)
        file = file_path.resolve()

        with(open(file=file, mode='w')) as fs:
            fs.write("测试地址=".encode("unicode_escape").decode() + host_url + '\n')
            fs.writelines("操作系统".encode("unicode_escape").decode() + "={0}".format(platform.system()) + '\n')
            fs.writelines("系统版本".encode("unicode_escape").decode() + "={0}".format(platform.version()) + '\n')
            fs.writelines("执行机名".encode("unicode_escape").decode() + "={0}".format(platform.node()) + '\n')
            fs.writelines("执行环境".encode("unicode_escape").decode() + "={0}".format(platform.python_build()))


if __name__ == "__main__":
    EnvGenerater.generate_env_file()
